==> org.polarsys.capella.test.diagram.common.ju.source_1.2.2.201812061536.jar: org/polarsys/capella/test/diagram/common/ju/step/tools/CreateContainerTool.java <==
/*******************************************************************************
 * Copyright (c) 2006, 2016 THALES GLOBAL SERVICES.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 * Contributors:
 *    Thales - initial API and implementation
 *******************************************************************************/
package org.polarsys.capella.test.diagram.common.ju.step.tools;

import static org.junit.Assert.assertFalse;

import org.eclipse.sirius.diagram.DDiagramElementContainer;
import org.polarsys.capella.test.diagram.common.ju.context.DiagramContext;

public class CreateContainerTool extends CreateAbstractDNodeTool<DDiagramElementContainer> {

  public CreateContainerTool(DiagramContext context, String toolName, String containerView) {
    super(context, toolName, containerView, DDiagramElementContainer.class);
  }

  public CreateContainerTool(DiagramContext context, String toolName, String containerView, String newIdentifier) {
    super(context, toolName, containerView, newIdentifier, DDiagramElementContainer.class);
  }

  public CreateContainerTool(DiagramContext context, String[] toolIdentifier, String containerView) {
    super(context, toolIdentifier, containerView, DDiagramElementContainer.class);
  }

  public CreateContainerTool(DiagramContext context, String[] toolIdentifier, String containerView, String newIdentifier) {
    super(context, toolIdentifier, containerView, newIdentifier, DDiagramElementContainer.class);
  }

  @Override
  protected void postRunTest() {
    super.postRunTest();

    if (!(newElements.iterator().next() instanceof DDiagramElementContainer)) {
      assertFalse(true);
    }

  }
}

==> org.polarsys.capella.test.diagram.common.ju.source_1.4.2.202010140908.jar: org/polarsys/capella/test/diagram/common/ju/step/tools/CreateContainerTool.java <==
/*******************************************************************************
 * Copyright (c) 2006, 2019 THALES GLOBAL SERVICES.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *    Thales - initial API and implementation
 *******************************************************************************/
package org.polarsys.capella.test.diagram.common.ju.step.tools;

import org.eclipse.sirius.diagram.DDiagramElementContainer;
import org.polarsys.capella.test.diagram.common.ju.context.DiagramContext;

public class CreateContainerTool extends CreateAbstractDNodeTool<DDiagramElementContainer> {

  public CreateContainerTool(DiagramContext context, String toolName, String containerView) {
    super(context, toolName, containerView, DDiagramElementContainer.class);
  }

  /*
   * Constructors deprecated due to the use of the "newIdentifier" variable 
   * This should not be used as it introduces problems with the Insert/Remove actions
   */
  @Deprecated
  public CreateContainerTool(DiagramContext context, String toolName, String containerView, String newIdentifier) {
    super(context, toolName, containerView, newIdentifier, DDiagramElementContainer.class);
  }

  @Deprecated
  public CreateContainerTool(DiagramContext context, String[] toolIdentifier, String containerView) {
    super(context, toolIdentifier, containerView, DDiagramElementContainer.class);
  }

  @Deprecated
  public CreateContainerTool(DiagramContext context, String[] toolIdentifier, String containerView,
      String newIdentifier) {
    super(context, toolIdentifier, containerView, newIdentifier, DDiagramElementContainer.class);
  }
}
